import Joi from 'joi';
import { Ability, SubjectRawRule, MongoQuery } from '@casl/ability';
import { AnyObject, ExtractSubjectType, Subject } from '@casl/ability/dist/types/types';
import { PackRule } from '@casl/ability/extra';
import { IdToken } from './auth-id-token';
import { BasicMetadata } from './auth-type-verify';
export declare enum AuthTokenType {
    Bearer = "Bearer",
    Basic = "Basic"
}
export declare enum AppDomain {
    MERCHANT = "MERCHANT",
    CONSUMER = "CONSUMER",
    ADMIN = "ADMIN",
    ROUTER = "ROUTER"
}
export declare type BaseIdToken = {
    userId: number;
    userName: string;
    localeCode: string;
    appDomain?: AppDomain;
    productId?: number;
};
export declare const schemaBaseIdToken: {
    userId: Joi.NumberSchema;
    userName: Joi.StringSchema;
    localeCode: Joi.StringSchema;
    appDomain: Joi.StringSchema;
    productId: Joi.NumberSchema;
};
export declare type AuthToken = {
    type: AuthTokenType;
    info: AccessInfo;
    grant?: boolean;
};
export declare type AccessInfo = {
    token: string;
    auth?: IdToken;
    authMetadata?: {
        basic?: BasicMetadata;
        rules?: PackRule<any>[];
    };
    headers?: {
        appDomain: AppDomain;
        localeCode: string;
    };
    requestedBy?: number;
    requestedByName?: string;
    ability: Ability;
};
export declare type Rule = {
    action: string;
    subject: string;
    fields?: string;
};
export declare type ClaimRule = SubjectRawRule<string, ExtractSubjectType<Subject>, MongoQuery<AnyObject>>;
export declare type AuthDirective = {
    type: AuthTokenType;
    hasAbility?: Rule;
};
export declare function generateAbility(rules?: ClaimRule[]): Ability<import("@casl/ability").AbilityTuple<string, Subject>, MongoQuery<AnyObject>>;
export declare function generateAbilityFromPackedRules(rules: PackRule<any>[]): Ability<import("@casl/ability").AbilityTuple<string, Subject>, MongoQuery<AnyObject>>;
